@@ -38,27 +38,29 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
-#include <libhal-gdevice.h>
-#include <libhal-gmanager.h>
-#include <libdbus-proxy.h>
+#include <hal-device.h>
+#include <hal-manager.h>
+#include "egg-dbus-proxy.h"
+
+#include "egg-debug.h"
+#include "egg-discrete.h"
 
 #include "gpm-common.h"
-#include "egg-debug.h"
 #include "gpm-light-sensor.h"
-#include "gpm-conf.h"
+#include <gconf/gconf-client.h>
 #include "gpm-marshal.h"
 
 #define GPM_LIGHT_SENSOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_LIGHT_SENSOR, GpmLightSensorPrivate))
 
 struct GpmLightSensorPrivate
 {
-	GpmConf			*conf;
+	GConfClient			*conf;
 	guint			 current_hw;		/* hardware */
 	guint			 levels;
 	gfloat			 calibration_abs;
 	gchar			*udi;
 	gboolean		 has_sensor;
-	DbusProxy		*gproxy;
+	EggDbusProxy		*gproxy;
 };
 
 enum {
@@ -92,7 +94,7 @@ gpm_light_sensor_get_hw (GpmLightSensor *sensor)
 	g_return_val_if_fail (sensor != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_LIGHT_SENSOR (sensor), FALSE);
 
-	proxy = dbus_proxy_get_proxy (sensor->priv->gproxy);
+	proxy = egg_dbus_proxy_get_proxy (sensor->priv->gproxy);
 	if (proxy == NULL) {
 		egg_warning ("not connected to HAL");
 		return FALSE;
@@ -147,7 +149,7 @@ gpm_light_sensor_get_absolute (GpmLightSensor *sensor,
 		return FALSE;
 	}
 
-	*sensor_level = gpm_discrete_to_percent (sensor->priv->current_hw,
+	*sensor_level = egg_discrete_to_percent (sensor->priv->current_hw,
 					         sensor->priv->levels);
 	return TRUE;
 }
@@ -171,7 +173,7 @@ gpm_light_sensor_calibrate (GpmLightSensor *sensor)
 		return FALSE;
 	}
 
-	fraction = gpm_discrete_to_fraction (sensor->priv->current_hw,
+	fraction = egg_discrete_to_fraction (sensor->priv->current_hw,
 					     sensor->priv->levels);
 	sensor->priv->calibration_abs = fraction;
 	egg_debug ("calibrating to %f", fraction);
@@ -201,7 +203,7 @@ gpm_light_sensor_get_relative (GpmLightSensor *sensor,
 		return FALSE;
 	}
 
-	absolute = gpm_discrete_to_percent (sensor->priv->current_hw,
+	absolute = egg_discrete_to_percent (sensor->priv->current_hw,
 					    sensor->priv->levels);
 	*difference = (absolute - sensor->priv->calibration_abs) + 1.0;
 	return TRUE;
@@ -241,8 +243,7 @@ gpm_light_sensor_class_init (GpmLightSensorClass *klass)
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (GpmLightSensorClass, sensor_changed),
-			      NULL,
-			      NULL,
+			      NULL, NULL,
 			      g_cclosure_marshal_VOID__UINT,
 			      G_TYPE_NONE,
 			      1,
@@ -258,9 +259,8 @@ gboolean
 gpm_light_sensor_has_hw (GpmLightSensor *sensor)
 {
 	g_return_val_if_fail (sensor != NULL, FALSE);
-	if (sensor->priv->has_sensor) {
+	if (sensor->priv->has_sensor)
 		return TRUE;
-	}
 	return FALSE;
 }
 
@@ -281,11 +281,9 @@ gpm_light_sensor_poll_cb (gpointer userdata)
 	sensor = GPM_LIGHT_SENSOR (userdata);
 
 	/* check if we should poll the h/w */
-	gpm_conf_get_bool (sensor->priv->conf, GPM_CONF_AMBIENT_ENABLE, &enable);
-	if (enable == FALSE) {
-		/* don't bother polling */
+	enable = gconf_client_get_bool (sensor->priv->conf, GPM_CONF_AMBIENT_ENABLE, NULL);
+	if (enable == FALSE)
 		return TRUE;
-	}
 
 	if (sensor->priv->has_sensor) {
 		/* fairly slow */
@@ -302,19 +300,6 @@ gpm_light_sensor_poll_cb (gpointer userdata)
 	return TRUE;
 }
 
-/**
- * conf_key_changed_cb:
- *
- * We might have to do things when the gconf keys change; do them here.
- **/
-static void
-conf_key_changed_cb (GpmConf     *conf,
-		     const gchar *key,
-		     GpmLightSensor *sensor)
-{
-	//
-}
-
 /**
  * gpm_light_sensor_init:
  * @sensor: This sensor class instance
@@ -327,23 +312,21 @@ static void
 gpm_light_sensor_init (GpmLightSensor *sensor)
 {
 	gchar **names;
-	HalGManager *manager;
-	HalGDevice *device;
+	HalManager *manager;
+	HalDevice *device;
 	guint timeout;
+	DBusGConnection *connection;
 
 	sensor->priv = GPM_LIGHT_SENSOR_GET_PRIVATE (sensor);
 	sensor->priv->udi = NULL;
 	sensor->priv->gproxy = NULL;
 	sensor->priv->udi = NULL;
 	sensor->priv->calibration_abs = 0.0f;
-
-	sensor->priv->conf = gpm_conf_new ();
-	g_signal_connect (sensor->priv->conf, "value-changed",
-			  G_CALLBACK (conf_key_changed_cb), sensor);
+	sensor->priv->conf = gconf_client_get_default ();
 
 	/* see if we can find  */
-	manager = hal_gmanager_new ();
-	hal_gmanager_find_capability (manager, "light_sensor", &names, NULL);
+	manager = hal_manager_new ();
+	hal_manager_find_capability (manager, "light_sensor", &names, NULL);
 	g_object_unref (manager);
 
 	/* Significant found */
@@ -352,23 +335,22 @@ gpm_light_sensor_init (GpmLightSensor *sensor)
 		sensor->priv->udi = g_strdup (names[0]);
 		sensor->priv->has_sensor = TRUE;
 	}
-	hal_gmanager_free_capability (names);
+	hal_manager_free_capability (names);
 
 	/* connect to the devices */
 	if (sensor->priv->has_sensor) {
 		egg_debug ("Using proper brightness sensor");
 		/* get a managed proxy */
-		sensor->priv->gproxy = dbus_proxy_new ();
-		dbus_proxy_assign (sensor->priv->gproxy,
-				  DBUS_PROXY_SYSTEM,
-				  HAL_DBUS_SERVICE,
-				  sensor->priv->udi,
-				  HAL_DBUS_INTERFACE_LIGHT_SENSOR);
+		sensor->priv->gproxy = egg_dbus_proxy_new ();
+		connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, NULL);
+		egg_dbus_proxy_assign (sensor->priv->gproxy,
+				  connection, HAL_DBUS_SERVICE,
+				  sensor->priv->udi, HAL_DBUS_INTERFACE_LIGHT_SENSOR);
 
 		/* get levels that the adapter supports -- this does not change ever */
-		device = hal_gdevice_new ();
-		hal_gdevice_set_udi (device, sensor->priv->udi);
-		hal_gdevice_get_uint (device, "light_sensor.num_levels",
+		device = hal_device_new ();
+		hal_device_set_udi (device, sensor->priv->udi);
+		hal_device_get_uint (device, "light_sensor.num_levels",
 				      &sensor->priv->levels, NULL);
 		g_object_unref (device);
 
@@ -381,8 +363,8 @@ gpm_light_sensor_init (GpmLightSensor *sensor)
 		egg_debug ("current brightness is %i%%", sensor->priv->current_hw);
 
 		/* get poll timeout */
-		gpm_conf_get_uint (sensor->priv->conf, GPM_CONF_AMBIENT_POLL, &timeout);
-		g_timeout_add (timeout * 1000, gpm_light_sensor_poll_cb, sensor);
+		timeout = gconf_client_get_int (sensor->priv->conf, GPM_CONF_AMBIENT_POLL, NULL);
+		g_timeout_add_seconds (timeout, gpm_light_sensor_poll_cb, sensor);
 	}
 }
 
