@@ -27,20 +27,22 @@
 
 #include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
+#include <errno.h>
+#include <locale.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <gtk/gtk.h>
 #include <glade/glade.h>
-#include <gst/gst.h>
 
 #include "gpm-stock-icons.h"
 #include "gpm-common.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 
 #include "gpm-manager.h"
-#include "dbus/xdg-power-management-core.h"
+#include "org.freedesktop.PowerManagement.h"
 
 /**
  * gpm_object_register:
@@ -73,12 +75,12 @@ gpm_object_register (DBusGConnection *connection,
 				 G_TYPE_UINT, &request_name_result,
 				 G_TYPE_INVALID);
 	if (error) {
-		gpm_debug ("ERROR: %s", error->message);
+		egg_debug ("ERROR: %s", error->message);
 		g_error_free (error);
 	}
-	if (ret == FALSE) {
+	if (!ret) {
 		/* abort as the DBUS method failed */
-		gpm_warning ("RequestName failed!");
+		egg_warning ("RequestName failed!");
 		return FALSE;
 	}
 
@@ -123,18 +125,13 @@ main (int argc, char *argv[])
 	DBusGConnection *session_connection;
 	gboolean verbose = FALSE;
 	gboolean version = FALSE;
-	gboolean no_daemon = FALSE;
 	gboolean timed_exit = FALSE;
 	gboolean immediate_exit = FALSE;
 	GpmManager *manager = NULL;
 	GError *error = NULL;
 	GOptionContext *context;
-	char **debugoptions = NULL;
-	int i;
 
 	const GOptionEntry options[] = {
-		{ "no-daemon", '\0', 0, G_OPTION_ARG_NONE, &no_daemon,
-		  N_("Do not daemonize"), NULL },
 		{ "verbose", '\0', 0, G_OPTION_ARG_NONE, &verbose,
 		  N_("Show extra debugging information"), NULL },
 		{ "version", '\0', 0, G_OPTION_ARG_NONE, &version,
@@ -143,87 +140,71 @@ main (int argc, char *argv[])
 		  N_("Exit after a small delay (for debugging)"), NULL },
 		{ "immediate-exit", '\0', 0, G_OPTION_ARG_NONE, &immediate_exit,
 		  N_("Exit after the manager has loaded (for debugging)"), NULL },
-		{ "debug", '\0', 0, G_OPTION_ARG_STRING_ARRAY, &debugoptions,
-		  N_("Debug specific files, e.g. power"), NULL },
 		{ NULL}
 	};
 
-	context = g_option_context_new (N_("GNOME Power Manager"));
-
+	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	if (! g_thread_supported ())
+		g_thread_init (NULL);
+	dbus_g_thread_init ();
+	g_type_init ();
+
+	context = g_option_context_new (N_("GNOME Power Manager"));
+	/* TRANSLATORS: program name, a simple app to view pending updates */
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	g_option_context_set_translation_domain(context, GETTEXT_PACKAGE);
-	g_option_context_add_group (context, gtk_get_option_group (FALSE));
+	g_option_context_set_summary (context, _("GNOME Power Manager"));
 	g_option_context_parse (context, &argc, &argv, NULL);
+	g_option_context_free (context);
 
-	/* manually poke gtk, it seems gtk_get_option_group isn't good enough */
-	gtk_init (&argc, &argv);
-
-	g_set_application_name (GPM_NAME);
-
-	if (version == TRUE) {
+	if (version) {
 		g_print ("Version %s\n", VERSION);
-		return 0;
+		goto unref_program;
 	}
 
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
 	dbus_g_thread_init ();
 
-	gpm_debug_init (verbose);
+	gtk_init (&argc, &argv);
+	egg_debug_init (verbose);
 
-	/* Add all of the options specified on the --debug line */
-	if (debugoptions) {
-		for (i = 0; debugoptions[i]; i++) {
-			gpm_debug_add_option (debugoptions[i]);
-		}
-	}
+	egg_debug ("GNOME %s %s", GPM_NAME, VERSION);
 
-	/* we need to daemonize before we get a system connection to fix #366057 */
-	if (no_daemon == FALSE && daemon (0, 0)) {
-		gpm_error ("Could not daemonize: %s", g_strerror (errno));
-	}
-
-	gpm_debug ("GNOME %s %s", GPM_NAME, VERSION);
-
-if (0) {
 	/* check dbus connections, exit if not valid */
 	system_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
 	if (error) {
-		gpm_warning ("%s", error->message);
+		egg_warning ("%s", error->message);
 		g_error_free (error);
-		gpm_error ("This program cannot start until you start "
+		egg_error ("This program cannot start until you start "
 			   "the dbus system service.\n"
 			   "It is <b>strongly recommended</b> you reboot "
 			   "your computer after starting this service.");
 	}
-}
 
 	session_connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (error) {
-		gpm_warning ("%s", error->message);
+		egg_warning ("%s", error->message);
 		g_error_free (error);
-		gpm_error ("This program cannot start until you start the "
+		egg_error ("This program cannot start until you start the "
 			   "dbus session service.\n\n"
 			   "This is usually started automatically in X "
 			   "or gnome startup when you start a new session.");
 	}
 
-	/* Add application specific icons to search path */
+	/* add application specific icons to search path */
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                            GPM_DATA G_DIR_SEPARATOR_S "icons");
 
-	/* initialise gstreamer */
-	gst_init (&argc, &argv);
-
 	/* create a new gui object */
 	manager = gpm_manager_new ();
 
 	if (!gpm_object_register (session_connection, G_OBJECT (manager))) {
-		gpm_error ("%s is already running in this session.", GPM_NAME);
+		egg_error ("%s is already running in this session.", GPM_NAME);
 		return 0;
 	}
 
@@ -231,8 +212,8 @@ if (0) {
 
 	/* Only timeout and close the mainloop if we have specified it
 	 * on the command line */
-	if (timed_exit == TRUE) {
-		g_timeout_add (1000 * 20, (GSourceFunc) timed_exit_cb, loop);
+	if (timed_exit) {
+		g_timeout_add_seconds (20, (GSourceFunc) timed_exit_cb, loop);
 	}
 
 	if (immediate_exit == FALSE) {
@@ -240,11 +221,9 @@ if (0) {
 	}
 
 	g_main_loop_unref (loop);
-	gpm_debug_shutdown ();
 
-	/* rip down gstreamer */
-	gst_deinit ();
 	g_object_unref (manager);
-
+unref_program:
+	g_option_context_free (context);
 	return 0;
 }
