@@ -26,12 +26,12 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 
-#include "gpm-conf.h"
+#include <gconf/gconf-client.h>
 #include "gpm-phone.h"
-#include "gpm-debug.h"
+#include "egg-debug.h"
 #include "gpm-marshal.h"
 
-#include <libdbus-watch.h>
+#include "egg-dbus-monitor.h"
 
 static void     gpm_phone_class_init (GpmPhoneClass *klass);
 static void     gpm_phone_init       (GpmPhone      *phone);
@@ -43,7 +43,7 @@ struct GpmPhonePrivate
 {
 	DBusGProxy		*proxy;
 	DBusGConnection		*connection;
-	DbusWatch		*watch;
+	EggDbusMonitor		*monitor;
 	gboolean		 present;
 	guint			 percentage;
 	gboolean		 onac;	 
@@ -76,14 +76,14 @@ gpm_phone_coldplug (GpmPhone *phone)
 	g_return_val_if_fail (GPM_IS_PHONE (phone), FALSE);
 
 	if (phone->priv->proxy == NULL) {
-		gpm_warning ("not connected\n");
+		egg_warning ("not connected\n");
 		return FALSE;
 	}
 
 	ret = dbus_g_proxy_call (phone->priv->proxy, "Coldplug", &error,
 				 G_TYPE_INVALID, G_TYPE_INVALID);
 	if (error != NULL) {
-		gpm_warning ("DEBUG: ERROR: %s", error->message);
+		egg_warning ("DEBUG: ERROR: %s", error->message);
 		g_error_free (error);
 	}
 
@@ -153,11 +153,11 @@ gpm_phone_battery_state_changed (DBusGProxy     *proxy,
 	g_return_if_fail (phone != NULL);
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
-	gpm_debug ("got BatteryStateChanged %i = %i (%i)", index, percentage, on_ac);
+	egg_debug ("got BatteryStateChanged %i = %i (%i)", index, percentage, on_ac);
 	phone->priv->percentage = percentage;
 	phone->priv->onac = on_ac;
 	phone->priv->present = TRUE;
-	gpm_debug ("emitting device-refresh : (%i)", index);
+	egg_debug ("emitting device-refresh : (%i)", index);
 	g_signal_emit (phone, signals [DEVICE_REFRESH], 0, index);
 }
 
@@ -171,9 +171,9 @@ gpm_phone_num_batteries_changed (DBusGProxy     *proxy,
 	g_return_if_fail (phone != NULL);
 	g_return_if_fail (GPM_IS_PHONE (phone));
 
-	gpm_debug ("got NumberBatteriesChanged %i", number);
+	egg_debug ("got NumberBatteriesChanged %i", number);
 	if (number > 1) {
-		gpm_warning ("number not 0 or 1, not valid!");
+		egg_warning ("number not 0 or 1, not valid!");
 		return;
 	}
 
@@ -182,13 +182,13 @@ gpm_phone_num_batteries_changed (DBusGProxy     *proxy,
 		phone->priv->present = FALSE;
 		phone->priv->percentage = 0;
 		phone->priv->onac = FALSE;
-		gpm_debug ("emitting device-removed : (%i)", 0);
+		egg_debug ("emitting device-removed : (%i)", 0);
 		g_signal_emit (phone, signals [DEVICE_REMOVED], 0, 0);
 		return;
 	}
 
 	if (phone->priv->present) {
-		gpm_warning ("duplicate NumberBatteriesChanged with no change");
+		egg_warning ("duplicate NumberBatteriesChanged with no change");
 		return;
 	}
 
@@ -196,7 +196,7 @@ gpm_phone_num_batteries_changed (DBusGProxy     *proxy,
 	phone->priv->present = TRUE;
 	phone->priv->percentage = 0;
 	phone->priv->onac = FALSE;
-	gpm_debug ("emitting device-added : (%i)", 0);
+	egg_debug ("emitting device-added : (%i)", 0);
 	g_signal_emit (phone, signals [DEVICE_ADDED], 0, 0);
 }
 
@@ -264,18 +264,18 @@ gpm_phone_dbus_connect (GpmPhone *phone)
 	g_return_val_if_fail (GPM_IS_PHONE (phone), FALSE);
 
 	if (phone->priv->connection == NULL) {
-		gpm_debug ("get connection\n");
+		egg_debug ("get connection\n");
 		g_clear_error (&error);
 		phone->priv->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 		if (error != NULL) {
-			gpm_warning ("Could not connect to DBUS daemon: %s", error->message);
+			egg_warning ("Could not connect to DBUS daemon: %s", error->message);
 			g_error_free (error);
 			phone->priv->connection = NULL;
 			return FALSE;
 		}
 	}
 	if (phone->priv->proxy == NULL) {
-		gpm_debug ("get proxy\n");
+		egg_debug ("get proxy\n");
 		g_clear_error (&error);
 		phone->priv->proxy = dbus_g_proxy_new_for_name_owner (phone->priv->connection,
 							 GNOME_PHONE_MANAGER_DBUS_SERVICE,
@@ -283,7 +283,7 @@ gpm_phone_dbus_connect (GpmPhone *phone)
 							 GNOME_PHONE_MANAGER_DBUS_INTERFACE,
 							 &error);
 		if (error != NULL) {
-			gpm_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			egg_warning ("Cannot connect, maybe the daemon is not running: %s\n", error->message);
 			g_error_free (error);
 			phone->priv->proxy = NULL;
 			return FALSE;
@@ -322,13 +322,13 @@ gpm_phone_dbus_disconnect (GpmPhone *phone)
 	g_return_val_if_fail (GPM_IS_PHONE (phone), FALSE);
 
 	if (phone->priv->proxy != NULL) {
-		gpm_debug ("removing proxy\n");
+		egg_debug ("removing proxy\n");
 		g_object_unref (phone->priv->proxy);
 		phone->priv->proxy = NULL;
 		if (phone->priv->present) {
 			phone->priv->present = FALSE;
 			phone->priv->percentage = 0;
-			gpm_debug ("emitting device-removed : (%i)", 0);
+			egg_debug ("emitting device-removed : (%i)", 0);
 			g_signal_emit (phone, signals [DEVICE_REMOVED], 0, 0);
 		}
 	}
@@ -336,13 +336,13 @@ gpm_phone_dbus_disconnect (GpmPhone *phone)
 }
 
 /**
- * watch_connection_cb:
+ * monitor_connection_cb:
  * @proxy: The dbus raw proxy
  * @status: The status of the service, where TRUE is connected
  * @screensaver: This class instance
  **/
 static void
-watch_connection_cb (DbusWatch *watch,
+monitor_connection_cb (EggDbusMonitor *monitor,
 		     gboolean   status,
 		     GpmPhone  *phone)
 {
@@ -360,6 +360,7 @@ watch_connection_cb (DbusWatch *watch,
 static void
 gpm_phone_init (GpmPhone *phone)
 {
+	DBusGConnection *connection;
 	phone->priv = GPM_PHONE_GET_PRIVATE (phone);
 
 	phone->priv->connection = NULL;
@@ -368,10 +369,11 @@ gpm_phone_init (GpmPhone *phone)
 	phone->priv->percentage = 0;
 	phone->priv->onac = FALSE;
 
-	phone->priv->watch = dbus_watch_new ();
-	g_signal_connect (phone->priv->watch, "connection-changed",
-			  G_CALLBACK (watch_connection_cb), phone);
-	dbus_watch_assign (phone->priv->watch, DBUS_WATCH_SESSION, GNOME_PHONE_MANAGER_DBUS_SERVICE);
+	phone->priv->monitor = egg_dbus_monitor_new ();
+	g_signal_connect (phone->priv->monitor, "connection-changed",
+			  G_CALLBACK (monitor_connection_cb), phone);
+	connection = dbus_g_bus_get (DBUS_BUS_SESSION, NULL);
+	egg_dbus_monitor_assign (phone->priv->monitor, connection, GNOME_PHONE_MANAGER_DBUS_SERVICE);
 	gpm_phone_dbus_connect (phone);
 }
 
@@ -390,9 +392,8 @@ gpm_phone_finalize (GObject *object)
 	phone->priv = GPM_PHONE_GET_PRIVATE (phone);
 
 	gpm_phone_dbus_disconnect (phone);
-	if (phone->priv->watch != NULL) {
-		g_object_unref (phone->priv->watch);
-	}
+	if (phone->priv->monitor != NULL)
+		g_object_unref (phone->priv->monitor);
 
 	G_OBJECT_CLASS (gpm_phone_parent_class)->finalize (object);
 }
@@ -416,13 +417,13 @@ gpm_phone_new (void)
 /***************************************************************************
  ***                          MAKE CHECK TESTS                           ***
  ***************************************************************************/
-#ifdef GPM_BUILD_TESTS
-#include "gpm-self-test.h"
+#ifdef EGG_TEST
+#include "egg-test.h"
 
 static gboolean test_got_refresh = FALSE;
 
 static void
-gpm_st_mainloop_wait (guint ms)
+egg_test_mainloop_wait (guint ms)
 {
 	GMainLoop *loop;
 	loop = g_main_loop_new (NULL, FALSE);
@@ -442,23 +443,23 @@ phone_device_refresh_cb (GpmPhone     *phone,
 }
 
 void
-gpm_st_phone (GpmSelfTest *test)
+gpm_phone_test (EggTest *test)
 {
 	GpmPhone *phone;
 	guint value;
 	gboolean ret;
 
-	if (gpm_st_start (test, "GpmPhone", CLASS_MANUAL) == FALSE) {
+	if (egg_test_start (test, "GpmPhone") == FALSE) {
 		return;
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we get a non null phone");
+	egg_test_title (test, "make sure we get a non null phone");
 	phone = gpm_phone_new ();
 	if (phone != NULL) {
-		gpm_st_success (test, "got GpmPhone");
+		egg_test_success (test, "got GpmPhone");
 	} else {
-		gpm_st_failed (test, "could not get GpmPhone");
+		egg_test_failed (test, "could not get GpmPhone");
 	}
 
 	/* connect signals */
@@ -466,71 +467,73 @@ gpm_st_phone (GpmSelfTest *test)
 			  G_CALLBACK (phone_device_refresh_cb), GUINT_TO_POINTER(44));
 
 	/************************************************************/
-	gpm_st_title (test, "make sure we got a connection");
+	egg_test_title (test, "make sure we got a connection");
 	if (phone->priv->proxy != NULL) {
-		gpm_st_success (test, "got connection");
+		egg_test_success (test, "got connection");
 	} else {
-		gpm_st_failed (test, "could not get a connection!");
+		/* skip this part of the test */
+		egg_test_success (test, "could not get a connection!");
+		goto out;
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "coldplug the data");
+	egg_test_title (test, "coldplug the data");
 	ret = gpm_phone_coldplug (phone);
 	if (ret) {
-		gpm_st_success (test, "coldplug okay");
+		egg_test_success (test, "coldplug okay");
 	} else {
-		gpm_st_failed (test, "could not coldplug");
+		egg_test_failed (test, "could not coldplug");
 	}
 
-	gpm_st_mainloop_wait (500);
+	egg_test_mainloop_wait (500);
 
 	/************************************************************/
-	gpm_st_title (test, "got refresh");
+	egg_test_title (test, "got refresh");
 	if (test_got_refresh) {
-		gpm_st_success (test, NULL);
+		egg_test_success (test, NULL);
 	} else {
-		gpm_st_failed (test, "did not get refresh");
+		egg_test_failed (test, "did not get refresh");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the connected phones");
+	egg_test_title (test, "check the connected phones");
 	value = gpm_phone_get_num_batteries (phone);
 	if (value == 1) {
-		gpm_st_success (test, "connected phone");
+		egg_test_success (test, "connected phone");
 	} else {
-		gpm_st_failed (test, "not connected with %i (phone not connected?)", value);
+		egg_test_failed (test, "not connected with %i (phone not connected?)", value);
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the present value");
+	egg_test_title (test, "check the present value");
 	ret = gpm_phone_get_present (phone, 0);
 	if (ret) {
-		gpm_st_success (test, "we are here!");
+		egg_test_success (test, "we are here!");
 	} else {
-		gpm_st_failed (test, "not here...");
+		egg_test_failed (test, "not here...");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the percentage");
+	egg_test_title (test, "check the percentage");
 	value = gpm_phone_get_percentage (phone, 0);
 	if (value != 0) {
-		gpm_st_success (test, "percentage is %i", phone->priv->percentage);
+		egg_test_success (test, "percentage is %i", phone->priv->percentage);
 	} else {
-		gpm_st_failed (test, "could not get value");
+		egg_test_failed (test, "could not get value");
 	}
 
 	/************************************************************/
-	gpm_st_title (test, "check the ac value");
+	egg_test_title (test, "check the ac value");
 	ret = gpm_phone_get_on_ac (phone, 0);
 	if (!ret) {
-		gpm_st_success (test, "not charging, correct");
+		egg_test_success (test, "not charging, correct");
 	} else {
-		gpm_st_failed (test, "charging?");
+		egg_test_failed (test, "charging?");
 	}
-
+out:
 	g_object_unref (phone);
 
-	gpm_st_end (test);
+	egg_test_end (test);
 }
 
 #endif
